==> flutter_snow_blower-0.0.1.tar.gz: lib/src/modules/start/create/clean/create_pages_files.dart <==
part of './create_clean_architecture.dart';

Future<void> _createPagesFiles(String package, bool complete) async {
  await Generate.module('app/pages/home', true, false);

  if (complete) {
    // ** splash
    createStaticFile(
      libPath('app/pages/splash/splash_page.dart'),
      templates.splashPageClean(),
    );
    createStaticFile(
      libPath('app/pages/splash/splash_controller.dart'),
      templates.splashControllerClean(package),
    );
    createStaticFile(libPath('app/pages/splash/splash_module.dart'),
        templates.splashModule());

    // ** login
    createStaticFile(
      libPath('app/pages/login/login_module.dart'),
      templates.loginModule(),
    );

    // i18n
    createStaticFile(
      libPath('app/i18n/login_i18n.dart'),
      templates.loginI18n(),
    );

    // widget
    createStaticFile(
      libPath('app/widgets/login/email_text_field_widget.dart'),
      templates.emailTextFieldWidget(),
    );
    createStaticFile(
      libPath('app/widgets/login/password_text_field_widget.dart'),
      templates.passwordTextFieldWidget(),
    );

    // page
    createStaticFile(
      libPath('app/pages/login/pages/login/login_page.dart'),
      templates.loginPage(package, Architecture.cleanArchitecture),
    );
    createStaticFile(
      libPath('app/pages/login/pages/login/login_controller.dart'),
      templates.loginControllerClean(package),
    );
    // ** register
    createStaticFile(
      libPath('app/pages/login/pages/register/register_page.dart'),
      templates.registerPage(package, Architecture.cleanArchitecture),
    );
    createStaticFile(
      libPath('app/pages/login/pages/register/register_controller.dart'),
      templates.registerControllerClean(package),
    );
  }
}

==> flutter_snow_blower-0.1.1.tar.gz: lib/src/modules/start/create/clean/create_pages_files.dart <==
part of './create_clean_architecture.dart';

Future<void> _createPagesFiles(String package, bool complete) async {
  await Generate.module('app/pages/home', true, false);

  createStaticFile(
    libPath('app/i18n/validators_i18n.dart'),
    templates.validatorsI18n(),
  );

  // Utils
  createStaticFile(
    libPath('app/utils/validators.dart'),
    templates.validators(Architecture.cleanArchitecture),
  );

  if (complete) {
    // ** splash
    createStaticFile(
      libPath('app/pages/splash/splash_page.dart'),
      templates.splashPageClean(),
    );
    createStaticFile(
      libPath('app/pages/splash/splash_controller.dart'),
      templates.splashControllerClean(package),
    );
    createStaticFile(libPath('app/pages/splash/splash_module.dart'),
        templates.splashModule());

    // ** login
    createStaticFile(
      libPath('app/pages/login/login_module.dart'),
      templates.loginModule(),
    );

    // i18n
    createStaticFile(
      libPath('app/i18n/login_i18n.dart'),
      templates.loginI18n(),
    );

    // widget
    createStaticFile(
      libPath('app/widgets/login/email_text_field_widget.dart'),
      templates.emailTextFieldWidget(
          package, "app", Architecture.cleanArchitecture),
    );
    createStaticFile(
      libPath('app/widgets/login/password_text_field_widget.dart'),
      templates.passwordTextFieldWidget(
          package, "app", Architecture.cleanArchitecture),
    );

    // page
    createStaticFile(
      libPath('app/pages/login/pages/login/login_page.dart'),
      templates.loginPage(package, Architecture.cleanArchitecture),
    );
    createStaticFile(
      libPath('app/pages/login/pages/login/login_controller.dart'),
      templates.loginControllerClean(package),
    );
    // ** register
    createStaticFile(
      libPath('app/pages/login/pages/register/register_page.dart'),
      templates.registerPage(package, Architecture.cleanArchitecture),
    );
    createStaticFile(
      libPath('app/pages/login/pages/register/register_controller.dart'),
      templates.registerControllerClean(package),
    );
  }
}
